@@ -12,12 +12,13 @@
 #![allow(clippy::derive_partial_eq_without_eq)]
 #![allow(clippy::result_large_err)]
 #![allow(clippy::unnecessary_map_on_constructor)]
+#![allow(clippy::deprecated_semver)]
 #![allow(rustdoc::bare_urls)]
 #![allow(rustdoc::redundant_explicit_links)]
 #![allow(rustdoc::invalid_html_tags)]
 #![forbid(unsafe_code)]
 #![warn(missing_docs)]
-#![cfg_attr(docsrs, feature(doc_auto_cfg))]
+#![cfg_attr(docsrs, feature(doc_cfg))]
 //! AWS IAM Identity Center (successor to AWS Single Sign-On) Portal is a web service that makes it easy for you to assign user access to IAM Identity Center resources such as the AWS access portal. Users can get AWS account applications and roles assigned to them and get federated into the application.
 //!
 //! This reference guide describes the IAM Identity Center Portal operations that you can call programatically and includes detailed information on data types and errors.
@@ -25,7 +26,7 @@
 //! ## Getting Started
 //!
 //! > Examples are available for many services and operations, check out the
-//! > [examples folder in GitHub](https://github.com/awslabs/aws-sdk-rust/tree/main/examples).
+//! > [usage examples](https://github.com/awsdocs/aws-doc-sdk-examples/tree/main/rustv1).
 //!
 //! The SDK provides one crate per AWS service. You must add [Tokio](https://crates.io/crates/tokio)
 //! as a dependency within your Rust project to execute asynchronous code. To add `aws-sdk-sso` to
@@ -34,7 +35,7 @@
 //! ```toml
 //! [dependencies]
 //! aws-config = { version = "1.1.7", features = ["behavior-version-latest"] }
-//! aws-sdk-sso = "1.83.0"
+//! aws-sdk-sso = "1.90.0"
 //! tokio = { version = "1", features = ["full"] }
 //! ```
 //!
@@ -68,7 +69,7 @@
 //! * [GitHub discussions](https://github.com/awslabs/aws-sdk-rust/discussions) - For ideas, RFCs & general questions
 //! * [GitHub issues](https://github.com/awslabs/aws-sdk-rust/issues/new/choose) - For bug reports & feature requests
 //! * [Generated Docs (latest version)](https://awslabs.github.io/aws-sdk-rust/)
-//! * [Usage examples](https://github.com/awslabs/aws-sdk-rust/tree/main/examples)
+//! * [Usage examples](https://github.com/awsdocs/aws-doc-sdk-examples/tree/main/rustv1)
 //!
 //!
 //! # Crate Organization
