@@ -118,11 +118,11 @@ use std::time::Duration;
 use time::OffsetDateTime;
 use tokio::time::Instant;
 
-const IMPERSONATED_CREDENTIAL_TYPE: &str = "imp";
+pub(crate) const IMPERSONATED_CREDENTIAL_TYPE: &str = "imp";
 pub(crate) const DEFAULT_LIFETIME: Duration = Duration::from_secs(3600);
-const MSG: &str = "failed to fetch token";
+pub(crate) const MSG: &str = "failed to fetch token";
 
-enum BuilderSource {
+pub(crate) enum BuilderSource {
     FromJson(Value),
     FromCredentials(Credentials),
 }
@@ -466,15 +466,17 @@ impl Builder {
     }
 }
 
-struct ImpersonatedCredentialComponents {
-    source_credentials: Credentials,
-    service_account_impersonation_url: String,
-    delegates: Option<Vec<String>>,
-    quota_project_id: Option<String>,
-    scopes: Option<Vec<String>>,
+pub(crate) struct ImpersonatedCredentialComponents {
+    pub(crate) source_credentials: Credentials,
+    pub(crate) service_account_impersonation_url: String,
+    pub(crate) delegates: Option<Vec<String>>,
+    pub(crate) quota_project_id: Option<String>,
+    pub(crate) scopes: Option<Vec<String>>,
 }
 
-fn build_components_from_json(json: Value) -> BuildResult<ImpersonatedCredentialComponents> {
+pub(crate) fn build_components_from_json(
+    json: Value,
+) -> BuildResult<ImpersonatedCredentialComponents> {
     let config =
         serde_json::from_value::<ImpersonatedConfig>(json).map_err(BuilderError::parsing)?;
 
@@ -502,7 +504,7 @@ fn build_components_from_json(json: Value) -> BuildResult<ImpersonatedCredential
     })
 }
 
-fn build_components_from_credentials(
+pub(crate) fn build_components_from_credentials(
     source_credentials: Credentials,
     service_account_impersonation_url: Option<String>,
 ) -> BuildResult<ImpersonatedCredentialComponents> {
