@@ -1,5 +1,6 @@
 use std::collections::HashMap;
 
+use indexmap::IndexMap;
 use serde::{Deserialize, Serialize};
 
 use crate::render::{BaseMenuItemPlaceholders, PlaceholderString};
@@ -493,6 +494,10 @@ pub struct MacOS {
 
     /// Required shell script logic to handle opened URL payloads.
     pub event_handler: Option<PlaceholderString>,
+
+    /// Set of extra properties for the Info.plist file.
+    /// These properties are not validated by `menuinst.`
+    pub info_plist_extra: Option<IndexMap<String, serde_json::Value>>,
 }
 
 #[derive(Serialize, Deserialize, Debug, Clone)]
