@@ -5,6 +5,7 @@ use crate::{
 
 /// A map from literals to the clauses that are watching them. Each literal
 /// forms a linked list of clauses that are all watching that literal.
+#[derive(Default)]
 pub(crate) struct WatchMap {
     // Note: the map is to a single clause, but clauses form a linked list, so
     // it is possible to go from one to the next
@@ -12,10 +13,14 @@ pub(crate) struct WatchMap {
 }
 
 impl WatchMap {
-    pub(crate) fn new() -> Self {
-        Self {
-            map: Mapping::new(),
-        }
+    #[cfg(feature = "diagnostics")]
+    pub fn len(&self) -> usize {
+        self.map.len()
+    }
+
+    #[cfg(feature = "diagnostics")]
+    pub fn size_in_bytes(&self) -> usize {
+        self.map.size_in_bytes()
     }
 
     /// Add the clause to the linked list of the literals that the clause is
@@ -100,7 +105,7 @@ pub struct WatchMapCursor<'a> {
     current: WatchNode,
 }
 
-impl<'a> WatchMapCursor<'a> {
+impl WatchMapCursor<'_> {
     /// Skip to the next node in the linked list. Returns `None` if there is no
     /// next node.
     pub fn next(mut self) -> Option<Self> {
