@@ -1223,7 +1223,7 @@ pub(crate) use unlikely;
 #[allow(unused_macros)]
 macro_rules! static_cast_i32 {
     ($v:expr_2021) => {
-        ::std::mem::transmute::<u32, i32>($v)
+        u32::cast_signed($v)
     };
 }
 #[allow(unused_imports)]
@@ -1234,7 +1234,7 @@ pub(crate) use static_cast_i32;
 macro_rules! static_cast_u32 {
     ($v:expr_2021) => {
         // #[allow(clippy::missing_transmute_annotations)]
-        ::std::mem::transmute::<i32, u32>($v)
+        i32::cast_unsigned($v)
     };
 }
 #[allow(unused_imports)]
@@ -1243,25 +1243,15 @@ pub(crate) use static_cast_u32;
 /// static cast to an i64
 macro_rules! static_cast_i64 {
     ($v:expr_2021) => {
-        ::std::mem::transmute::<u64, i64>($v)
+        u64::cast_signed($v)
     };
 }
 pub(crate) use static_cast_i64;
 
-/// static cast to an i64
-#[cfg(all(feature = "approx-number-parsing", feature = "i128"))]
-macro_rules! static_cast_i128 {
-    ($v:expr_2021) => {
-        ::std::mem::transmute::<_, i128>($v)
-    };
-}
-#[cfg(all(feature = "approx-number-parsing", feature = "i128"))]
-pub(crate) use static_cast_i128;
-
 /// static cast to an u64
 macro_rules! static_cast_u64 {
     ($v:expr_2021) => {
-        ::std::mem::transmute::<i64, u64>($v)
+        i64::cast_unsigned($v)
     };
 }
 pub(crate) use static_cast_u64;
